
result_list = []

georow_list = ['rome', 'ny', 'seattle']
result_list.extend(georow_list)

georow_list.clear()
#georow_list = ['boston', 'LA', 'denver']
georow_list = []
result_list.extend(georow_list)

georow_list.clear()
georow_list.extend(result_list)

print(georow_list)



